<?php
/**
 * @file
 * Plugin to provide access control based upon node UUID.
 */

$plugin = array(
  'title' => t("Section: Name"),
  'description' => t('Control access by section->name.'),
  'callback' => 'section_section_name_ctools_access_check',
  'default' => array('name' => array()),
  'settings form' => 'section_section_name_ctools_access_settings',
  'summary' => 'section_section_name_ctools_access_summary',
  'required context' => new ctools_context_required(t('Section'), 'entity'),
);

/**
 * Settings form for the 'by section_name' access plugin
 */
function section_section_name_ctools_access_settings($form, &$form_state, $conf) {
  $form['settings']['name'] = array(
    '#title' => t('Section name'),
    '#type' => 'textfield',
    '#description' => t('Enter the section name.'),
    '#default_value' => $conf['name'],
    '#autocomplete_path' => 'section/autocomplete',
  );
  return $form;
}

/**
 * Check for access.
 */
function section_section_name_ctools_access_check($conf, $context) {

  // If we dont have the required variables, return FALSE.
  if (empty($context->data->name) || empty($context->data) || empty ($conf['name'])) {
    return FALSE;
  }

  // If the data->uuid is the same as we set, return TRUE.
  if ($context->data->name == $conf['name']) {
    return TRUE;
  }
  return FALSE;
}

/**
 * Provide a summary description based upon the checked node UUID.
 */
function section_section_name_ctools_access_summary($conf, $context) {
  if (!isset($conf['name'])) {
    $conf['type'] = array();
  }

  if (empty($conf['name'])) {
    return t('@identifier has name', array('@identifier' => $context->identifier));
  }

  return format_plural(count($conf['name']), '@identifier has name "@name"', '@identifier name is one of "@name"', array('@name' => $conf['name'], '@identifier' => $context->identifier));
}
