<?php
/**
 * @file
 * Context plugin.
 */

/**
 * Plugins are described by creating a $plugin array which will be used
 * by the system that includes this file.
 */
$plugin = array(
  'title' => t("Section"),
  'description' => t('A single section object.'),
  'context' => 'ctools_context_create_section',
  'edit form' => 'ctools_context_section_settings_form',
  'defaults' => array('section_name' => ''),
  'keyword' => 'section',
  'context name' => 'section',
  'convert list' => 'ctools_context_section_convert_list',
  'convert' => 'ctools_context_section_convert',
  'convert default' => 'section_name',
);

/**
 * It's important to remember that $conf is optional here, because contexts
 * are not always created from the UI.
 */
function ctools_context_create_section($empty, $data = NULL, $conf = FALSE, $plugin) {
  $context = new ctools_context(array('entity:section', 'entity', 'section'));
  $context->plugin = 'section';

  if ($empty) {
    return $context;
  }

  if ($conf) {
    if (isset($data['section_name'])) {
      $data = section_load($data['section_name']);
    }
  }

  if (!empty($data)) {
    $context->data     = $data;
    $context->title    = $data->label;
    $context->argument = $data->name;
    return $context;
  }
}

/**
 * Settings form.
 */
function ctools_context_section_settings_form($form, &$form_state) {
  $conf = $form_state['conf'];
  $plugin = &$form_state['plugin'];

  $form['section'] = array(
    '#title' => t('Enter the name of a @entity entity', array('@entity' => $plugin['keyword'])),
    '#type' => 'textfield',
    '#maxlength' => 512,
    '#autocomplete_path' => 'section/autocomplete',
    '#weight' => -10,
    '#default_value' => $conf['section_name'],
  );

  $form['section_name'] = array(
    '#type' => 'value',
    '#value' => $conf['section_name'],
  );

  $form['entity_type'] = array(
    '#type' => 'value',
    '#value' => $plugin['keyword'],
  );

  return $form;
}

/**
 * Validate a node.
 */
function ctools_context_section_settings_form_validate($form, &$form_state) {
  // Validate the autocomplete.
  if (empty($form_state['values']['section_name']) && empty($form_state['values']['section'])) {
    form_error($form['entity'], t('You must select an section.'));
    return;
  }

  if (empty($form_state['values']['section'])) {
    return;
  }

  $section_name = $form_state['values']['section'];

  if (!empty($section_name)) {
    $entity = section_load($section_name);
  }

  if (!$entity) {
    form_error($form['section'], t('Invalid section selected.'));
  }
  else {
    form_set_value($form['section_name'], $entity->name, $form_state);
  }
}

/**
 * Settings form submit handler.
 */
function ctools_context_section_settings_form_submit($form, &$form_state) {
  $form_state['conf']['section_name'] = $form_state['values']['section'];
}

/**
 * Provide a list of ways that this context can be converted to a string.
 */
function ctools_context_section_convert_list() {
  $list = array();
  $tokens = token_info();
  foreach ($tokens['tokens']['section'] as $id => $info) {
    if (!isset($list[$id])) {
      $list[$id] = $info['name'];
    }
  }

  return $list;
}

/**
 * Convert a context into a string.
 */
function ctools_context_section_convert($context, $type) {
  $tokens = token_info();
  if (isset($tokens['tokens']['section'][$type])) {
    $values = token_generate('section', array($type => $type), array('section' => $context->data));
    if (isset($values[$type])) {
      return $values[$type];
    }
  }
}
