<?php
/**
 * @file
 * export_ui plugin for section.
 */

$plugin = array(
  'schema' => 'section_bundle',
  'access' => 'administer section bundles',
  'create access' => 'create section bundles',
  'delete access' => 'delete section bundles',
  'menu' => array(
    'menu item' => 'section_bundle',
    'menu title' => 'Section types',
    'menu description' => 'Administer section bundles',
  ),
  'title singular' => t('Section type'),
  'title plural' => t('Section types'),
  'title singular proper' => t('Section type'),
  'title plural proper' => t('Section types'),
  'export' => array(
    'admin_title' => 'label',
  ),
  'form' => array(
    'settings' => 'section_export_ui_form',
    'submit' => 'section_export_ui_form_submit',
  ),
);

/**
 * Form; Add / Edit a section bundle.
 */
function section_export_ui_form(&$form, &$form_state) {
  ctools_include('export');
  $bundle = $form_state['item'];
  $settings = unserialize($bundle->settings);

  $form['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#default_value' => $bundle->description,
  );

  $form['additional_settings'] = array(
    '#type' => 'vertical_tabs',
    '#weight' => 99,
  );

  if (module_exists('menu')) {
    $menu_options = menu_get_menus();

    $form['menu'] = array(
      '#type' => 'fieldset',
      '#title' => t('Menu settings'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'additional_settings',
      '#attached' => array(
        'js' => array(drupal_get_path('module', 'menu') . '/menu.admin.js'),
      ),
    );
    $form['menu']['menu_options'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Available menus'),
      '#default_value' => isset($settings['menu_options']) ? $settings['menu_options'] : array('main-menu'),
      '#options' => $menu_options,
      '#description' => t('The menus available to place links in for this section type.'),
    );

    // To avoid an 'illegal option' error after saving the form we have to load
    // all available menu items.
    // Otherwise it is not possible to dynamically add options to the list.
    // @todo Convert menu_parent_options() into a #process callback.
    $options = menu_parent_options(menu_get_menus(), array('mlid' => 0));
    $form['menu']['menu_parent'] = array(
      '#type' => 'select',
      '#title' => t('Default parent item'),
      '#default_value' =>  isset($settings['menu_parent']) ? $settings['menu_parent'] : 'main-menu:0',
      '#options' => $options,
      '#description' => t('Choose the menu item to be the default parent for a new link in the section authoring form.'),
      '#attributes' => array('class' => array('menu-title-select')),
    );
  }

  $form['workflow'] = array(
    '#type' => 'fieldset',
    '#title' => t('Publishing options'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#group' => 'additional_settings',
  );
  $form['workflow']['section_options'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Default options'),
    '#default_value' => isset($settings['section_options']) ? $settings['section_options'] : array(),
    '#options' => array(
      'published' => t('Published'),
      'revision' => t('Create new revision'),
    ),
  );

  // Call Drupal.menu_update_parent_list() to filter the list of
  // available default parent menu items based on the selected menus.
  drupal_add_js(
    '(function ($) { Drupal.menu_update_parent_list(); })(jQuery);',
    array('scope' => 'footer', 'type' => 'inline')
  );

  return $form;
}

/**
 * Submit callback; Presave a section bundle.
 */
function section_export_ui_form_submit(&$form, &$form_state) {
  $settings = array();

  if (module_exists('menu')) {
    $settings['menu_options'] = array_filter($form_state['values']['menu_options']);
    $settings['menu_parent'] = $form_state['values']['menu_parent'];
  }

  $settings['section_options'] = $form_state['values']['section_options'];

  $form_state['item']->description = $form_state['values']['description'];
  $form_state['item']->settings = serialize($settings);
}

/**
 * Save callback; Save a section bundle.
 */
function section_bundle_save($bundle) {
  $schema = ctools_export_get_schema('section_bundle');
  $export = $schema['export'];

  // Objects should have a serial primary key. If not, simply fail to write.
  if (empty($export['primary key'])) {
    return FALSE;
  }

  $key = $export['primary key'];
  if ($bundle->export_type & EXPORT_IN_DATABASE) {
    // Existing record.
    $update = array($key);
  }
  else {
    // New record.
    $update = array();
    $bundle->export_type = EXPORT_IN_DATABASE;
  }
  $status = drupal_write_record('section_bundle', $bundle, $update);

  $t_args = array('%name' => $bundle->label);

  if ($status == SAVED_UPDATED) {
    drupal_set_message(t('The section type %name has been updated.', $t_args));
  }
  elseif ($status == SAVED_NEW) {
    section_bundle_add_body_field($bundle);
    drupal_set_message(t('The section type %name has been added.', $t_args));
    watchdog('section', 'Added section bundle %name.', $t_args, WATCHDOG_NOTICE, l(t('view'), 'admin/structure/section_bundle'));
  }

  // Clear the entity info cache.
  entity_get_controller('section')->resetCache();

  // Reset the static variable as this dosent know about the bundle we just
  // saved.
  drupal_static_reset('ctools_export_load_object');
  drupal_static_reset('ctools_export_load_object_all');

  // Rebuild the menu tree.
  menu_rebuild();

  return $status;
}


/**
 * Delete callback; Deletes a section bundle.
 */
function section_bundle_delete($object) {
  $schema = ctools_export_get_schema('section_bundle');
  $export = $schema['export'];

  // If we were sent an object, get the export key from it. Otherwise
  // assume we were sent the export key.
  $value = is_object($object) ? $object->{$export['key']} : $object;
  db_delete('section_bundle')
    ->condition($export['key'], $value)
    ->execute();

  // Clear the entity info cache.
  entity_get_controller('section')->resetCache();

  // Reset the static variable as this dosent know about the bundle we just
  // saved.
  drupal_static_reset('ctools_export_load_object');
  drupal_static_reset('ctools_export_load_object_all');

  // Rebuild the menu tree.
  menu_rebuild();
}
