<?php
/**
 * @file
 * Admin specific stuff for section.
 */

/**
 * Menu callback: section administration.
 */
function section_admin_section($form, $form_state) {
  if (isset($form_state['values']['operation']) && $form_state['values']['operation'] == 'delete') {
    return node_multiple_delete_confirm($form, $form_state, array_filter($form_state['values']['nodes']));
  }

  // $form['filter'] = node_filter_form();
  $form['#submit'][] = 'node_filter_form_submit';
  $form['admin'] = section_admin_sections();

  return $form;
}

/**
 * Form builder: Builds the section administration overview.
 */
function section_admin_sections() {
  $admin_access = user_access('administer sections');

  // Build the sortable table header.
  $header = array(
    'title' => array('data' => t('Label'), 'field' => 's.label'),
    'type' => array('data' => t('Type'), 'field' => 's.bundle'),
    'published' => array('data' => t('Status'), 'field' => 's.published'),
  );

  $header['operations'] = array('data' => t('Operations'));

  $query = db_select('section', 's')->extend('PagerDefault')->extend('TableSort');

  $sids = $query
    ->fields('s', array('sid'))
    ->limit(50)
    ->orderByHeader($header)
    ->execute()
    ->fetchCol();
  $sections = section_load_multiple($sids);

  // Prepare the list of sections.
  $destination = drupal_get_destination();
  $options = array();
  foreach ($sections as $section) {
    $options[$section->sid] = array(
      'title' => array(
        'data' => array(
          '#type' => 'link',
          '#title' => $section->label,
          '#href' => 'section/' . $section->sid,
        ),
      ),
      'type' => check_plain(section_bundle_get_name($section)),
      'published' => $section->published ? t('published') : t('not published'),
    );

    // Build a list of all the accessible operations for the current node.
    $operations = array();
    if (section_access('update', $section)) {
      $operations['edit'] = array(
        'title' => t('edit'),
        'href' => 'section/' . $section->sid . '/edit',
        'query' => $destination,
      );
    }
    if (section_access('delete', $section)) {
      $operations['delete'] = array(
        'title' => t('delete'),
        'href' => 'section/' . $section->sid . '/delete',
        'query' => $destination,
      );
    }
    $options[$section->sid]['operations'] = array();
    if (count($operations) > 1) {
      // Render an unordered list of operations links.
      $options[$section->sid]['operations'] = array(
        'data' => array(
          '#theme' => 'links__node_operations',
          '#links' => $operations,
          '#attributes' => array('class' => array('links', 'inline')),
        ),
      );
    }
    elseif (!empty($operations)) {
      // Render the first and only operation as a link.
      $link = reset($operations);
      $options[$section->sid]['operations'] = array(
        'data' => array(
          '#type' => 'link',
          '#title' => $link['title'],
          '#href' => $link['href'],
          '#options' => array('query' => $link['query']),
        ),
      );
    }
  }

  // Only use a tableselect when the current user is able to perform any
  // operations.
  if ($admin_access) {
    $form['sections'] = array(
      '#type' => 'tableselect',
      '#header' => $header,
      '#options' => $options,
      '#empty' => t('No sections available.'),
    );
  }
  // Otherwise, use a simple table.
  else {
    $form['sections'] = array(
      '#theme' => 'table',
      '#header' => $header,
      '#rows' => $options,
      '#empty' => t('No sections available.'),
    );
  }

  $form['pager'] = array('#markup' => theme('pager'));
  return $form;
}
