<?php
/**
 * @file
 * Code for pathauto integration.
 */

/**
 * Batch processing callback; Generate aliases for sections.
 */
function section_pathauto_bulk_update_batch_process(&$context) {
  if (!isset($context['sandbox']['current'])) {
    $context['sandbox']['count'] = 0;
    $context['sandbox']['current'] = 0;
  }

  $query = db_select('section', 's');
  $query->leftJoin('url_alias', 'ua', "CONCAT('section/', s.sid) = ua.source");
  $query->addField('s', 'sid');
  $query->isNull('ua.source');
  $query->condition('s.sid', $context['sandbox']['current'], '>');
  $query->orderBy('s.sid');
  $query->addTag('pathauto_bulk_update');
  $query->addMetaData('entity', 'section');

  // Get the total amount of items to process.
  if (!isset($context['sandbox']['total'])) {
    $context['sandbox']['total'] = $query->countQuery()->execute()->fetchField();

    // If there are no nodes to update, the stop immediately.
    if (!$context['sandbox']['total']) {
      $context['finished'] = 1;
      return;
    }
  }

  $query->range(0, 25);
  $sids = $query->execute()->fetchCol();

  section_update_alias_multiple($sids, 'bulkupdate');
  $context['sandbox']['count'] += count($sids);
  $context['sandbox']['current'] = max($sids);
  $context['message'] = t('Updated alias for section @sid.', array('@sid' => end($sids)));

  if ($context['sandbox']['count'] != $context['sandbox']['total']) {
    $context['finished'] = $context['sandbox']['count'] / $context['sandbox']['total'];
  }
}
