<?php
/**
 * @file
 * Code for search integration.
 */

/**
 * Implements hook_search_info().
 */
function section_search_info() {
  return array(
    'title' => 'Section',
    'path' => 'section',
  );
}

/**
 * Implements hook_search_access().
 */
function section_search_access() {
  return user_access('access content');
}

/**
 * Implements hook_search_reset().
 */
function section_search_reset() {
  db_update('search_dataset')
    ->fields(array('reindex' => REQUEST_TIME))
    ->condition('type', 'section')
    ->execute();
}

/**
 * Implements hook_update_index().
 */
function section_update_index() {
  $limit = (int)variable_get('search_cron_limit', 100);

  $result = db_query_range("SELECT s.sid FROM {section} s LEFT JOIN {search_dataset} d ON d.type = 'section' AND d.sid = s.sid WHERE d.sid IS NULL OR d.reindex <> 0 ORDER BY d.reindex ASC, s.sid ASC", 0, $limit, array(), array('target' => 'slave'));

  foreach ($result as $section) {
    _section_index_section($section);
  }
}

/**
 * Index a single section.
 *
 * @param $section
 *   The section to index.
 */
function _section_index_section($section) {
  $section = section_load($section->sid);

  // Save the changed time of the most recent indexed node, for the search
  // results half-life calculation.
  //variable_set('node_cron_last', $section->changed);

  // Render the section.
  $build = section_view($section, 'search_index');
  unset($build['#theme']);
  $section->rendered = drupal_render($build);

  $text = '<h1>' . check_plain($section->label) . '</h1>' . $section->rendered;

  // Fetch extra data normally not visible
  $extra = module_invoke_all('section_update_index', $section);
  foreach ($extra as $t) {
    $text .= $t;
  }

  // Update index
  search_index($section->sid, 'section', $text);
}


/**
 * Implements hook_search_execute().
 */
function section_search_execute($keys = NULL, $conditions = NULL) {
  // Build matching conditions
  $query = db_select('search_index', 'i', array('target' => 'slave'))->extend('SearchQuery')->extend('PagerDefault');
  $query->join('section', 's', 's.sid = i.sid');
  
  $query
    //->condition('n.status', 1)
    ->addTag('section_access')
    ->searchExpression($keys, 'section');

  // Insert special keywords.
  //$query->setOption('type', 'n.type');
  //$query->setOption('language', 'n.language');
  if ($query->setOption('term', 'ti.tid')) {
    $query->join('taxonomy_index', 'ti', 's.sid = ti.nid');
  }
  // Only continue if the first pass query matches.
  if (!$query->executeFirstPass()) {
    return array();
  }

  // Add the ranking expressions.
  //_node_rankings($query);

  // Load results.
  $find = $query
    ->limit(10)
    ->execute();
  $results = array();
 
  foreach ($find as $item) {
    // Render the node.
    $section = section_load($item->sid);
    $build = section_view($section, 'search_result');
    unset($build['#theme']);
    $section->rendered = drupal_render($build);

    // Fetch comments for snippet.
    $section->rendered .= ' ' . module_invoke('comment', 'section_update_index', $section);

    $extra = module_invoke_all('section_search_result', $section);

    $uri = entity_uri('section', $section);
    $results[] = array(
      'link' => url($uri['path'], array_merge($uri['options'], array('absolute' => TRUE))),
      //'type' => check_plain(node_type_get_name($node)),
      'title' => $section->label,
      'user' => theme('username', array('account' => $section)),
      //'date' => $section->changed,
      'section' => $section,
      'extra' => $extra,
      //'score' => $item->calculated_score,
      'snippet' => search_excerpt($keys, $section->rendered),
      //'language' => $section->language,
    );
  }
  return $results;
}
