<?php

/**
 * @file
 * Builds placeholder replacement tokens for section-related data.
 */

/**
 * Implements hook_token_info().
 */
function section_token_info() {
  $type = array(
    'name' => t('Sections'),
    'description' => t('Tokens related to individual sections.'),
    'needs-data' => 'section',
  );

  $section['sid'] = array(
    'name' => t("Section ID"),
    'description' => t('The unique ID of the section.'),
  );

  $section['label'] = array(
    'name' => t("Section label"),
    'description' => t('The label of the section.'),
  );

  $section['name'] = array(
    'name' => t("Section name"),
    'description' => t('The machine name of the section.'),
  );

  $section['bundle'] = array(
    'name' => t("Section type"),
    'description' => t("The type of the section."),
  );

  $section['bundle-name'] = array(
    'name' => t("Section type name"),
    'description' => t("The human-readable name of the section type."),
  );

  $section['url'] = array(
    'name' => t("URL"),
    'description' => t("The URL of the section."),
  );
  $section['edit-url'] = array(
    'name' => t("Edit URL"),
    'description' => t("The URL of the section's edit page."),
  );

  return array(
    'types' => array('section' => $type),
    'tokens' => array('section' => $section),
  );
}

/**
 * Implements hook_tokens().
 */
function section_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $url_options = array('absolute' => TRUE);
  $sanitize = !empty($options['sanitize']);

  $replacements = array();

  if ($type == 'section' && !empty($data['section'])) {
    $section = $data['section'];

    foreach ($tokens as $name => $original) {
      switch ($name) {
        // Simple key values on the node.
        case 'sid':
          $replacements[$original] = $section->sid;
          break;

        case 'name':
          $replacements[$original] = $section->name;
          break;

        case 'label':
          $replacements[$original] = $sanitize ? check_plain($section->label) : $section->label;
          break;

        case 'bundle':
          $replacements[$original] = $sanitize ? check_plain($section->bundle) : $section->bundle;
          break;

        case 'bundle-name':
          $bundle_name = section_bundle_get_name($section);
          $replacements[$original] = $sanitize ? check_plain($bundle_name) : $bundle_name;
          break;

        case 'url':
          $replacements[$original] = url('section/' . $section->name, $url_options);
          break;

        case 'edit-url':
          $replacements[$original] = url('section/' . $section->name . '/edit', $url_options);
          break;
      }
    }
  }

  return $replacements;
}
